@@ -21,14 +21,23 @@ class OrderedMessageHandler:
 
     :param google.pubsub_v1.services.subscriber.client.SubscriberClient subscriber: a Google Pub/Sub subscriber
     :param octue.cloud.pub_sub.subscription.Subscription subscription: the subscription messages are pulled from
+    :param callable|None handle_monitor_message: a function to handle monitor messages (e.g. send them to an endpoint for plotting or displaying) - this function should take a single JSON-compatible python primitive
     :param str service_name: an arbitrary name to refer to the service subscribed to by (used for labelling its remote log messages)
     :param dict|None message_handlers: a mapping of message handler names to callables that handle each type of message
     :return None:
     """
 
-    def __init__(self, subscriber, subscription, service_name="REMOTE", message_handlers=None):
+    def __init__(
+        self,
+        subscriber,
+        subscription,
+        handle_monitor_message=None,
+        service_name="REMOTE",
+        message_handlers=None,
+    ):
         self.subscriber = subscriber
         self.subscription = subscription
+        self.handle_monitor_message = handle_monitor_message
         self.service_name = service_name
 
         self.received_delivery_acknowledgement = None
@@ -38,6 +47,7 @@ class OrderedMessageHandler:
 
         self._message_handlers = message_handlers or {
             "delivery_acknowledgement": self._handle_delivery_acknowledgement,
+            "monitor_message": self._handle_monitor_message,
             "log_record": self._handle_log_message,
             "exception": self._handle_exception,
             "result": self._handle_result,
@@ -164,6 +174,17 @@ class OrderedMessageHandler:
         self.received_delivery_acknowledgement = True
         logger.info("%r's question was delivered at %s.", self.subscription.topic.service, message["delivery_time"])
 
+    def _handle_monitor_message(self, message):
+        """Send a monitor message to the handler if one has been provided.
+
+        :param dict message:
+        :return None:
+        """
+        logger.debug("%r received a monitor message.", self.subscription.topic.service)
+
+        if self.handle_monitor_message is not None:
+            self.handle_monitor_message(json.loads(message["data"]))
+
     def _handle_log_message(self, message):
         """Deserialise the message into a log record and pass it to the local log handlers, adding [<service-name>] to
         the start of the log message.
