@@ -3,6 +3,7 @@ from .cool_nameable import CoolNameable
 from .filterable import Filterable
 from .hashable import Hashable
 from .identifiable import Identifiable
+from .labelable import Labelable
 from .loggable import Loggable
 from .pathable import Pathable
 from .serialisable import Serialisable
@@ -14,6 +15,7 @@ __all__ = (
     "Filterable",
     "Hashable",
     "Identifiable",
+    "Labelable",
     "Loggable",
     "MixinBase",
     "Pathable",
