@@ -174,6 +174,9 @@ class Datafile(Labelable, Taggable, Serialisable, Pathable, Loggable, Identifiab
     def __repr__(self):
         return f"<{type(self).__name__}({self.name!r})>"
 
+    def __str__(self):
+        return repr(self)
+
     @classmethod
     def deserialise(cls, serialised_datafile, path_from=None):
         """Deserialise a Datafile from a dictionary. The `path_from` parameter is only used if the path in the
