@@ -74,15 +74,17 @@ class Runner:
         input_manifest=None,
         analysis_log_level=logging.INFO,
         analysis_log_handler=None,
+        handle_monitor_message=None,
     ):
-        """Run an analysis
+        """Run an analysis.
 
         :param str|None analysis_id: UUID of analysis
         :param Union[str, dict, None] input_values: the input_values strand data. Can be expressed as a string path of a *.json file (relative or absolute), as an open file-like object (containing json data), as a string of json data or as an already-parsed dict.
         :param Union[str, octue.resources.manifest.Manifest, None] input_manifest: The input_manifest strand data. Can be expressed as a string path of a *.json file (relative or absolute), as an open file-like object (containing json data), as a string of json data or as an already-parsed dict.
         :param str analysis_log_level: the level below which to ignore log messages
         :param logging.Handler|None analysis_log_handler: the logging.Handler instance which will be used to handle logs for this analysis run. Handlers can be created as per the logging cookbook https://docs.python.org/3/howto/logging-cookbook.html but should use the format defined above in LOG_FORMAT.
-        :return: None
+        :param callable|None handle_monitor_message: a function that sends monitor messages to the parent that requested the analysis
+        :return None:
         """
         if hasattr(self.twine, "credentials"):
             self._populate_environment_with_google_cloud_secrets()
@@ -107,7 +109,7 @@ class Runner:
                 for child in inputs["children"]
             }
 
-        outputs_and_monitors = self.twine.prepare("monitors", "output_values", "output_manifest", cls=CLASS_MAP)
+        outputs_and_monitors = self.twine.prepare("monitor_message", "output_values", "output_manifest", cls=CLASS_MAP)
 
         # TODO this is hacky, we need to rearchitect the twined validation so we can do this kind of thing in there
         outputs_and_monitors["output_manifest"] = self._update_manifest_path(
@@ -138,8 +140,9 @@ class Runner:
 
         analysis = Analysis(
             id=analysis_id,
-            logger=analysis_logger,
             twine=self.twine,
+            handle_monitor_message=handle_monitor_message,
+            logger=analysis_logger,
             skip_checks=self.skip_checks,
             **self.configuration,
             **inputs,
